@@ -393,7 +393,7 @@ sub wait_until_port_open {
         close $socket
           or Carp::croak("Failed to close test socket:$EXTENDED_OS_ERROR");
     }
-    return;
+    return $found_port;
 }
 
 sub directory {
@@ -1060,7 +1060,7 @@ sub new {
     if ( -d $git_repo_dir ) {
         system {'git'} 'git', 'submodule', 'init'
           and Carp::croak("Failed to 'git submodule init':$EXTENDED_OS_ERROR");
-        system {'git'} 'git', 'submodule', 'update', '--remote'
+        system {'git'} 'git', 'submodule', 'update'
           and
           Carp::croak("Failed to 'git submodule update':$EXTENDED_OS_ERROR");
     }
